@@ -1,22 +1,28 @@
 ## ---- include = FALSE----------------------------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
+  eval = pdftools::poppler_config()$can_render,
   comment = "#>"
 )
 
+knitr::opts_knit$set(root.dir = tempdir())
+
 ## ----setup---------------------------------------------------------------
 library(slickR)
 
 ## ------------------------------------------------------------------------
-url <- 'https://cran.r-project.org/web/packages/slickR/slickR.pdf'
+
+pdf_file <- system.file('examples/slickR.pdf',package = 'slickR')
+
+imgs <- pdftools::pdf_convert(pdf_file,format = 'png',verbose = FALSE)
 
 
 ## ------------------------------------------------------------------------
-slickpdf(url, slideId = 'ex1')
-
+slickR(imgs,height = 500)
 
 ## ------------------------------------------------------------------------
-slickpdf(obj = url, obj2 = url, 
-         slideId = c('ex2up','ex2down'))
+bottom_opts <- settings(arrows = FALSE,slidesToShow = 3,slidesToScroll = 1,centerMode = TRUE, focusOnSelect = TRUE,initialSlide = 0)
+
+slickR(imgs,height = 500) %synch% (slickR(imgs,height = 100) + bottom_opts)
 
 
